@@ -123,6 +123,7 @@ types_converter_dict = {
             "null": "String",
             "timestamp": "Datetime",
             "timestamp without time zone": "Datetime",
+            "timestamp with time zone": "Datetime",
             "time without time zone": "String",
             "int2": "Int8",
             "int4": "Int8",
@@ -134,7 +135,9 @@ types_converter_dict = {
             "numeric": "Float32",
             "double_precision": "Float64",
             "double precision": "Float64",
-            "user-defined": "String"
+            "user-defined": "String",
+            "int4range": "String",
+            "tstzrange": "String"
         },
         "default": {"false": 0, "true": 1},
     },
