@@ -121,9 +121,9 @@ class FieldsConverter:
         type_from = column["data_type"]
         types_conv = types_converter_dict[self.key]["type"]
         if type_from in types_conv:
-            type_to = types_conv[type_from]
+            type_to = types_conv[type_from.lower()]
         else:
-            type_to = type_from
+            type_to = type_from.lower()
 
         if column["character_maximum_length"] is not None and type_to not in "text" and self.to_db != 'ch':
             max_length_mult = base_converter_params[self.to_db]["max_length_mult"]
